emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

master 05af964 1/2: Merge from origin/emacs-28


From: Stefan Kangas
Subject: master 05af964 1/2: Merge from origin/emacs-28
Date: Wed, 8 Dec 2021 07:20:50 -0500 (EST)

branch: master
commit 05af96456c0c056b61be30e53e2592a8d155de54
Merge: 58cf601 ce5bca4
Author: Stefan Kangas <stefan@marxist.se>
Commit: Stefan Kangas <stefan@marxist.se>

    Merge from origin/emacs-28
    
    ce5bca4913 Document native-comp-async-report-warning-errors more
    1933cd5307 Doc fix; Epiphany has been renamed to GNOME Web
    b80d7568e4 * lisp/dired-aux.el (dired-check-process): Doc fix.  (Bug#...
    0f30227f97 ; * lisp/net/browse-url.el (browse-url-epiphany): Fix typo.
    d34009db66 Remove dead link from newsticker
    
    # Conflicts:
    #   lisp/net/browse-url.el
---
 doc/lispref/compile.texi  | 12 +++++++++++-
 lisp/dired-aux.el         | 14 ++++++++------
 lisp/net/browse-url.el    | 20 ++++++++++----------
 lisp/net/newst-backend.el |  3 +--
 lisp/net/newsticker.el    |  3 +--
 5 files changed, 31 insertions(+), 21 deletions(-)

diff --git a/doc/lispref/compile.texi b/doc/lispref/compile.texi
index 523758c..1ca1f66 100644
--- a/doc/lispref/compile.texi
+++ b/doc/lispref/compile.texi
@@ -924,7 +924,11 @@ of the main Emacs process.  This leaves the main Emacs 
process free to
 use while the compilation runs in the background.  This is the method
 used by Emacs to natively-compile any Lisp file or byte-compiled Lisp
 file that is loaded into Emacs, when no natively-compiled file for it
-is available.
+is available.  Note that because of this use of a subprocess, native
+compilation may produce warning and errors which byte-compilation does
+not, and lisp code may thus need to be modified to work correctly.  See
+@code{native-comp-async-report-warnings-errors} in @pxref{Native-Compilation
+Variables} for more details.
 
 @defun native-compile-async files &optional recursively load selector
 This function compiles the named @var{files} asynchronously.  The
@@ -1038,6 +1042,12 @@ Emacs session in a buffer named @file{*Warnings*}.  The 
default value
 @code{t} means display the resulting buffer.  To log warnings without
 popping up the @file{*Warnings*} buffer, set this variable to
 @code{silent}.
+
+  A common cause for asynchronous native-compilation to produce
+warnings is compiling a file that is missing some @code{require} of a
+necessary feature.  The feature may be loaded into the main emacs, but
+because native compilation always starts from a subprocess with a
+pristine environment, that may not be true for the subprocess.
 @end defopt
 
 @defopt native-comp-async-query-on-exit
diff --git a/lisp/dired-aux.el b/lisp/dired-aux.el
index af7b160..5301a3a 100644
--- a/lisp/dired-aux.el
+++ b/lisp/dired-aux.el
@@ -992,12 +992,14 @@ prompted for the shell command to use interactively."
 
 
 (defun dired-check-process (msg program &rest arguments)
-  "Display MSG while running PROGRAM, and check for output.
-Remaining arguments are strings passed as command arguments to PROGRAM.
-On error, insert output
-in a log buffer and return the offending ARGUMENTS or PROGRAM.
-Caller can cons up a list of failed args.
-Else returns nil for success."
+  "Display MSG, then run PROGRAM, and log any error messages from it.
+ARGUMENTS should be strings to be passed to PROGRAM as command-line
+arguments.
+
+If PROGRAM exits successfully, display \"MSG...done\" and return nil.
+If PROGRAM exits abnormally, save in `dired-log-buffer' the command
+that invoked PROGRAM and the messages it emitted, and return either
+the offending ARGUMENTS or PROGRAM if no ARGUMENTS were provided."
   (let (err-buffer err (dir default-directory))
     (message "%s..." msg)
     (save-excursion
diff --git a/lisp/net/newst-backend.el b/lisp/net/newst-backend.el
index efbff79..77e1480 100644
--- a/lisp/net/newst-backend.el
+++ b/lisp/net/newst-backend.el
@@ -1204,8 +1204,7 @@ URL 
`http://www.atompub.org/2005/08/17/draft-ietf-atompub-format-11.html'"
 Return value as well as arguments NAME, TIME, and TOPNODE are the
 same as in `newsticker--parse-atom-1.0'.
 
-For the RSS 0.91 specification see URL `http://backend.userland.com/rss091'
-or URL `http://my.netscape.com/publish/formats/rss-spec-0.91.html'."
+For the RSS 0.91 specification see URL `http://backend.userland.com/rss091'."
   (newsticker--debug-msg "Parsing RSS 0.91 feed %s" name)
   (let* ((channelnode (car (xml-get-children topnode 'channel)))
          is-new-feed has-new-items)
diff --git a/lisp/net/newsticker.el b/lisp/net/newsticker.el
index 34e94ac..c171421 100644
--- a/lisp/net/newsticker.el
+++ b/lisp/net/newsticker.el
@@ -43,8 +43,7 @@
 ;; are contained in "RSS" (RDF Site Summary) or "Atom" files.  Newsticker
 ;; should work with the following RSS formats:
 ;;  * RSS 0.91
-;;    (see http://backend.userland.com/rss091 or
-;;    http://my.netscape.com/publish/formats/rss-spec-0.91.html)
+;;    (see http://backend.userland.com/rss091)
 ;;  * RSS 0.92
 ;;    (see http://backend.userland.com/rss092)
 ;;  * RSS 1.0



reply via email to

[Prev in Thread] Current Thread [Next in Thread]
diff --git a/lisp/net/browse-url.el b/lisp/net/browse-url.el
index d317256..2be9c7c 100644
--- a/lisp/net/browse-url.el
+++ b/lisp/net/browse-url.el
@@ -38,7 +38,7 @@
 ;; browse-url-firefox                 Firefox     Don't know (tried with 1.0.1)
 ;; browse-url-chrome                  Chrome      47.0.2526.111
 ;; browse-url-chromium                Chromium    3.0
-;; browse-url-epiphany                Epiphany    Don't know
+;; browse-url-epiphany                GNOME Web (Epiphany)    Don't know
 ;; browse-url-webpositive             WebPositive 1.2-alpha (Haiku R1/beta3)
 ;; browse-url-w3                      w3          0
 ;; browse-url-text-*                 Any text browser     0
@@ -156,7 +156,7 @@
     (function-item :tag "Firefox" :value browse-url-firefox)
     (function-item :tag "Google Chrome" :value browse-url-chrome)
     (function-item :tag "Chromium" :value browse-url-chromium)
-    (function-item :tag "Epiphany" :value  browse-url-epiphany)
+    (function-item :tag "GNOME Web (Epiphany)" :value  browse-url-epiphany)
     (function-item :tag "WebPositive" :value browse-url-webpositive)
     (function-item :tag "Text browser in an xterm window"
                   :value browse-url-text-xterm)
@@ -305,15 +305,15 @@ Defaults to the value of `browse-url-firefox-arguments' 
at the time
   :version "24.1")
 
 (defcustom browse-url-epiphany-program "epiphany"
-  "The name by which to invoke Epiphany."
+  "The name by which to invoke GNOME Web (Epiphany)."
   :type 'string)
 
 (defcustom browse-url-epiphany-arguments nil
-  "A list of strings to pass to Epiphany as arguments."
+  "A list of strings to pass to GNOME Web (Epiphany) as arguments."
   :type '(repeat (string :tag "Argument")))
 
 (defcustom browse-url-epiphany-startup-arguments browse-url-epiphany-arguments
-  "A list of strings to pass to Epiphany when it starts up.
+  "A list of strings to pass to GNOME Web (Epiphany) when it starts up.
 Defaults to the value of `browse-url-epiphany-arguments' at the time
 `browse-url' is loaded."
   :type '(repeat (string :tag "Argument")))
@@ -1131,12 +1131,12 @@ The optional argument NEW-WINDOW is not used."
 (function-put 'browse-url-chrome 'browse-url-browser-kind 'external)
 
 (defun browse-url-epiphany (url &optional new-window)
-  "Ask the Epiphany WWW browser to load URL.
+  "Ask the GNOME Web (Epiphany) WWW browser to load URL.
 Default to the URL around or before point.  The strings in variable
-`browse-url-galeon-arguments' are also passed to Epiphany.
+`browse-url-epiphany-arguments' are also passed to GNOME Web.
 
 When called interactively, if variable `browse-url-new-window-flag' is
-non-nil, load the document in a new Epiphany window, otherwise use a
+non-nil, load the document in a new GNOME Web window, otherwise use a
 random existing one.  A non-nil interactive prefix argument reverses
 the effect of `browse-url-new-window-flag'.
 
@@ -1168,10 +1168,10 @@ used instead of `browse-url-new-window-flag'."
 (function-put 'browse-url-epiphany 'browse-url-browser-kind 'external)
 
 (defun browse-url-epiphany-sentinel (process url)
-  "Handle a change to the process communicating with Epiphany."
+  "Handle a change to the process communicating with GNOME Web (Epiphany)."
   (or (eq (process-exit-status process) 0)
       (let* ((process-environment (browse-url-process-environment)))
        ;; Epiphany is not running - start it
        (message "Starting %s..." browse-url-epiphany-program)
        (apply #'start-process (concat "epiphany " url) nil
               browse-url-epiphany-program
@@ -1168,10 +1168,10 @@ used instead of `browse-url-new-window-flag'."
   (or (eq (process-exit-status process) 0)
       (let* ((process-environment (browse-url-process-environment)))
-       ;; Epiphany is not running - start it
+        ;; GNOME Web is not running - start it
        (message "Starting %s..." browse-url-epiphany-program)
        (apply #'start-process (concat "epiphany " url) nil